summaryrefslogtreecommitdiff
path: root/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
diff options
context:
space:
mode:
authorRĂ¼diger Timm <rt@openoffice.org>2004-11-26 15:36:11 +0000
committerRĂ¼diger Timm <rt@openoffice.org>2004-11-26 15:36:11 +0000
commit0b346159036180fc49cd5622f80a24f01130c9a7 (patch)
tree3ef3289afe81fb435b11816a74418cfc3db92a50 /comphelper/inc/comphelper/embeddedobjectcontainer.hxx
parent15d272a8cc18729f31abc6a5060038e05b23d5e7 (diff)
INTEGRATION: CWS leanobjects (1.2.32); FILE MERGED
2004/11/22 09:19:31 mba 1.2.32.2: #i37278#: some problems with moving and copying objects 2004/11/19 14:57:05 mba 1.2.32.1: #i37278#: allow to load objects on demand
Diffstat (limited to 'comphelper/inc/comphelper/embeddedobjectcontainer.hxx')
-rw-r--r--comphelper/inc/comphelper/embeddedobjectcontainer.hxx15
1 files changed, 10 insertions, 5 deletions
diff --git a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
index 54b6bfb649e5..8fd204daa934 100644
--- a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
+++ b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: embeddedobjectcontainer.hxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: kz $ $Date: 2004-10-04 21:05:39 $
+ * last change: $Author: rt $ $Date: 2004-11-26 16:36:11 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -143,10 +143,13 @@ public:
::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >
InsertEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::io::XInputStream >&, ::rtl::OUString& );
- // copy an embedded object into the storage and create another object from it
- ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject > CopyEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, ::rtl::OUString& );
+ // copy an embedded object into the storage
+ sal_Bool CopyEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, ::rtl::OUString& );
- // remove an embedded object from the container and from the storage
+ // move an embedded object from one container to another one
+ sal_Bool MoveEmbeddedObject( EmbeddedObjectContainer& rSrc, const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, ::rtl::OUString& );
+
+ // remove an embedded object from the container and from the storage; if object can't be closed
sal_Bool RemoveEmbeddedObject( const ::rtl::OUString& rName, sal_Bool bClose=sal_True );
sal_Bool RemoveEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, sal_Bool bClose=sal_True );
@@ -161,6 +164,8 @@ public:
// remove a graphical representation for an object
sal_Bool RemoveGraphicStream( const ::rtl::OUString& rObjectName );
+
+ void CloseEmbeddedObjects();
};
};